#ifndef SPLINES_H
#define SPLINES_H

#include <vector>
#include "Vec3.h"
#include <GL/glut.h>

/* This struct makes it easier for us to use multiple curves per level*/
struct Nodes
{
	std::vector<Vec3> controlPoints;	///< Holds the control points for a curve
	int closure;				///< Toggle for the closure of a curve
};

class Splines
{
public:
	std::vector<Nodes> levelCurves;		///< The control points for an individual level

	///< The control point that we have selected in picking mode (can only select points on current level)
	int objectPicked;		
	int WindowWidth, WindowHeight;		///< The width and height of the window
	int level;			///< Essentially the height that the control points will be placed
	GLenum renderMode;			///< Flag for rendering and selection mode
	int currentCurve;

	// only level 0 should use this, all other levels should use the copy constructor
	Splines(){
		renderMode = GL_RENDER; objectPicked=-1; level=0; currentCurve=0;
		Nodes node;
		levelCurves.push_back(node);
		levelCurves[0].closure=0;
	}
	
	Splines(const Splines &);			///< Copy constructor
	
	/* Set the window size, so that we can convert window coordinates
	 * to our x, y-coordinates.
	 */
	void setWindowSize(int width, int height)
	{
		WindowWidth=width;WindowHeight=height;
		if(levelCurves[0].controlPoints.size()==0)
		{
			addControlPoint(.4*WindowWidth, .4*WindowHeight);
			addControlPoint(.6*WindowWidth, .4*WindowHeight);
			addControlPoint(.6*WindowWidth, .6*WindowHeight);
			addControlPoint(.4*WindowWidth, .6*WindowHeight);
		}
	}
	
	/*
	 * Add a new curve to the current level and automatically
	 * start it off with 4 points.
	 */
	void addNewCurve()
	{
		Nodes node; levelCurves.push_back(node);currentCurve++;
		levelCurves[currentCurve].closure=0;
		addControlPoint(.4*WindowWidth, .4*WindowHeight);
		addControlPoint(.6*WindowWidth, .4*WindowHeight);
		addControlPoint(.6*WindowWidth, .6*WindowHeight);
		addControlPoint(.4*WindowWidth, .6*WindowHeight);
	}
	
	void nextCurve(){currentCurve = (currentCurve+1) % levelCurves.size();}
	void prevCurve(){currentCurve = (currentCurve-1) % levelCurves.size();}
	void closeCurve(){levelCurves[currentCurve].closure=1;}
	void openCurve(){levelCurves[currentCurve].closure=0;}
	void addControlPoint(int x, int y);
	void deleteControlPoint();
	void interpolatedPoint(float t, int i, float newPoint[3], int curve);
	void drawSpline(int currentLevel);
	void drawGrid();
	void drawControlPoints(int currentLevel);
	void drawCatmullRom();
};	// end Splines

#endif	// SPLINES_H
