/*
 *	Beginning of a level editor to be used in iLevel.  The user lays down
 *	control points for the catmull-rom spline to create their levels.  You
 *	can see four levels at any one time.
 *	
 *	@file iLevelEditor.cpp
 *	@author	Doug Nachand
 *	@created July 26, 2001
 *	@last modified February 14, 2002
 */
#include <vector>
#include "Graphics.h"
#include "FileIO.h"
Graphics *graphics;	// Handle to the graphics routines
FileIO *input = new FileIO();	// Handle to reading/writing files

void display()
{
	graphics->Display();
}
void reshape(int width, int height)
{
	graphics->Reshape(width, height);
}
void mouse(int button, int state, int x, int y)
{
	graphics->Mouse(button, state, x, y);
}
void mousemoved(int x, int y)
{
	graphics->MouseMoved(x, y);
}
void keyboard(unsigned char key, int x, int y)
{
	graphics->Keyboard(key, x, y);
}
void idle()
{
	graphics->Idle();
}
void specialKeyboard(int key, int x, int y)
{
	graphics->SpecialKeyboard(key, x, y);
}

// Process command line arguments
void arguments(int argc, char** argv)
{ 
	while(--argc)
	{
		++argv;
		if (argv[0][0] == '-')
		{
			switch (argv[0][1])
			{
				case 'i': 
				{
					++argv;
					argc--;
					input->setInputName(argv[0]);
					break; 
				}
				case 'o' :
				{
					++argv;
					argc--;
					input->setOutputName(argv[0]);
				}

			}
		}
	}
}

int main(int argc, char **argv)
{
	arguments(argc, argv);
	graphics=new Graphics(input);
	glutInitDisplayMode(GLUT_DOUBLE | GLUT_RGBA);
	glutInitWindowSize(640, 480);
	glutInitWindowPosition(150, 150);
	glutCreateWindow("iLevel Editor");
	graphics->DrawingSetup();
	glutDisplayFunc(display);
	glutIdleFunc(idle);
	glutReshapeFunc(reshape);
	glutMouseFunc(mouse);
	glutMotionFunc(mousemoved);
	glutPassiveMotionFunc(mousemoved);
	glutKeyboardFunc(keyboard);
	glutSpecialFunc(specialKeyboard);
	glutMainLoop();

	return 0;
}
